
.. py:currentmodule:: pythreejs

PointLightHelper
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: PointLightHelper(light=None, sphereSize=1, color="#ffffff", )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/helpers/PointLightHelper


    .. py:attribute:: light

        .. sourcecode:: python

            Instance(PointLight, allow_none=True).tag(sync=True, **widget_serialization)

    .. py:attribute:: sphereSize

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

    .. py:attribute:: color

        .. sourcecode:: python

            Unicode("#ffffff", allow_none=True).tag(sync=True)

